## Simple diagram
```python linenums="1"
--8<-- "simple_rbd.py:13:13,16:"
```

--8<-- "simple_rbd.py:4:8"

<img width="500" src='examples/simple_RBD.svg'/>


## Example with more functionality

```python linenums="1"
--8<-- "example_rbd.py:14:14,17:"
```

--8<-- "example_rbd.py:4:8"

<div class="highlight"><img width="1000" src='examples/example_RBD.svg'/></div>
